download_AWS_INMET_daily: Download of hourly data from automatic weather stations (AWS) of INMET-Brazil in daily aggregates
Description
This function will download the hourly AWS data of INMET and it will aggregate the data in a daily time scale, based on the period of time selected (start_date and end_date).The function only works for downloading data from the same year.