Learn R Programming

BrazilMet (version 0.2.0)

see_stations_info: Localization of the automatic weather station of INMET

Description

Function to see the localization of the automatic weather station of INMET.

Usage

see_stations_info()

Arguments

Value

A data.frame with informations of OMM code, latitude, longitude and altitude of all AWS stations available in INMET.

Author

Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha

Examples

Run this code
if (FALSE) {
see_stations_info()
}

Run the code above in your browser using DataLab